@@ -5,6 +5,6 @@ test_that("crossref responds correctly", {
   skip_on_cran()
   
   mssg <- "Crossref functionality moved to package rcrossref"
-  expect_error(crossref(), mssg)
-  expect_error(crossref(a = 5), mssg)
+  expect_error(crossref(), mssg, class="error")
+  expect_error(crossref(a = 5), mssg, class="error")
 })
