@@ -1,6 +1,8 @@
-# tests for highbrow fxn in rplos
 context("highbrow")
 
+skip_on_cran()
+skip_if_offline()
+
 test_that("highbrow", {
   vcr::use_cassette("highbrow", {
     out <- highplos(q = 'alcohol', hl.fl = 'abstract', rows = 10)
