@@ -1,6 +1,8 @@
-# tests for highplos fxn in rplos
 context("highplos")
 
+skip_on_cran()
+skip_if_offline()
+
 test_that("highplos", {
   vcr::use_cassette("highplos", {
     aa <- highplos(q='alcohol', hl.fl = 'abstract', rows=10)
