@@ -1,6 +1,8 @@
-# tests for journalnamekey fxn in rplos
 context("journalnamekey")
 
+skip_on_cran()
+skip_if_offline()
+
 test_that("journalnamekey returns the correct value", {
 	vcr::use_cassette("journalnamekey1", {
   	expect_true(grepl("PLoSONE", paste0(journalnamekey(), collapse = " ")))
