@@ -1,6 +1,8 @@
-# tests for plostitle fxn in rplos
 context("plostitle")
 
+skip_on_cran()
+skip_if_offline()
+
 test_that("plostitle returns the correct dimensionsed data.frame", {
 	vcr::use_cassette("plostitle", {
 		expect_that(nrow(plostitle(q='drosophila', fl='title', limit=19)$data),
