@@ -1,6 +1,8 @@
-# tests for plosviews fxn in rplos
 context("plosviews")
 
+skip_on_cran()
+skip_if_offline()
+
 test_that("plosviews returns the correct value", {
 	vcr::use_cassette("plosviews_values", {
 		expect_equal(plosviews('10.1371/journal.pone.0002154', 'id', 'alltime')$id,
